(* Copyright 2001, 2002 b8_bavard, b8_fee_carabine, INRIA *)
(*
    This file is part of mldonkey.

    mldonkey is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    mldonkey is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mldonkey; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)
type event =
  CONNECTION of Unix.file_descr * Unix.sockaddr
| BASIC_EVENT of BasicSocket.event
  
type t
type handler = t -> event -> unit

val sock : t -> BasicSocket.t
val create : string -> Unix.inet_addr -> int -> ?backlog:int -> handler -> t
val close : t -> BasicSocket.close_reason -> unit
val debug : bool ref
  
type connections_controler    
val set_accept_controler : t -> connections_controler -> unit
val create_connections_controler : string -> (int -> int -> bool) -> connections_controler
  